# Form implementation generated from reading ui file 'template2.ui'
#
# Created by: PyQt6 UI code generator 6.1.0
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


import os
from os.path import dirname, normpath

from PyQt6 import QtCore, QtGui, QtWidgets
from PyQt6.QtCore import QDir


class Ui_Form(object):
    def setupUi(self, Form):
        prefix_resources = [
            ("icons", "../resources/icons"),
            ("other_images", "../resources/"),
            ("other_icons", "../resources/icons"),
            ("images", "../resources/"),
        ]
        for prefix, resource in prefix_resources:
            sp = QDir.searchPaths(prefix)
            QDir.setSearchPaths(
                prefix, set(sp + [normpath(os.path.join(dirname(__file__), resource))])
            )

        Form.setObjectName("Form")
        Form.resize(292, 208)
        self.gridLayout = QtWidgets.QGridLayout(Form)
        self.gridLayout.setObjectName("gridLayout")
        self.label = QtWidgets.QLabel(Form)
        self.label.setText("")
        self.label.setPixmap(QtGui.QPixmap("images:image1.png"))
        self.label.setObjectName("label")
        self.gridLayout.addWidget(self.label, 2, 0, 1, 1)
        self.pushButton_3 = QtWidgets.QPushButton(Form)
        icon = QtGui.QIcon()
        icon.addPixmap(
            QtGui.QPixmap("other_images:image1_r2.png"),
            QtGui.QIcon.Mode.Normal,
            QtGui.QIcon.State.Off,
        )
        self.pushButton_3.setIcon(icon)
        self.pushButton_3.setObjectName("pushButton_3")
        self.gridLayout.addWidget(self.pushButton_3, 0, 1, 1, 1)
        self.label_2 = QtWidgets.QLabel(Form)
        self.label_2.setText("")
        #         self.label_2.setPixmap(QtGui.QPixmap(":/images_non_existent/image2.png"))
        self.label_2.setObjectName("label_2")
        self.gridLayout.addWidget(self.label_2, 2, 1, 1, 1)
        self.pushButton_4 = QtWidgets.QPushButton(Form)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(
            QtGui.QPixmap("other_icons:icon2_r2.png"),
            QtGui.QIcon.Mode.Normal,
            QtGui.QIcon.State.Off,
        )
        icon1.addPixmap(
            QtGui.QPixmap("icons:icon1.png"),
            QtGui.QIcon.Mode.Normal,
            QtGui.QIcon.State.On,
        )
        self.pushButton_4.setIcon(icon1)
        self.pushButton_4.setObjectName("pushButton_4")
        self.gridLayout.addWidget(self.pushButton_4, 1, 1, 1, 1)
        self.pushButton = QtWidgets.QPushButton(Form)
        icon2 = QtGui.QIcon()
        icon2.addPixmap(
            QtGui.QPixmap("icons:icon1.png"),
            QtGui.QIcon.Mode.Normal,
            QtGui.QIcon.State.Off,
        )
        self.pushButton.setIcon(icon2)
        self.pushButton.setObjectName("pushButton")
        self.gridLayout.addWidget(self.pushButton, 0, 0, 1, 1)
        self.pushButton_2 = QtWidgets.QPushButton(Form)
        icon3 = QtGui.QIcon()
        icon3.addPixmap(
            QtGui.QPixmap("icons:icon2.png"),
            QtGui.QIcon.Mode.Normal,
            QtGui.QIcon.State.Off,
        )
        self.pushButton_2.setIcon(icon3)
        self.pushButton_2.setObjectName("pushButton_2")
        self.gridLayout.addWidget(self.pushButton_2, 1, 0, 1, 1)
        self.label_3 = QtWidgets.QLabel(Form)
        self.label_3.setText("")
        self.label_3.setPixmap(QtGui.QPixmap("other_images:image1_r2.png"))
        self.label_3.setObjectName("label_3")
        self.gridLayout.addWidget(self.label_3, 3, 0, 1, 1)
        self.label_4 = QtWidgets.QLabel(Form)
        self.label_4.setText("")
        self.label_4.setPixmap(QtGui.QPixmap("other_images:image2_r2.png"))
        self.label_4.setObjectName("label_4")
        self.gridLayout.addWidget(self.label_4, 3, 1, 1, 1)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(_translate("Form", "Form"))
        self.pushButton_3.setText(_translate("Form", "PushButton"))
        self.pushButton_4.setText(_translate("Form", "PushButton"))
        self.pushButton.setText(_translate("Form", "PushButton"))
        self.pushButton_2.setText(_translate("Form", "PushButton"))



import logging


def set_logger(disabled: bool = False) -> None:
    logging.basicConfig(format="%(levelname)s - %(message)s", level=logging.INFO)
    logger = logging.getLogger("main")
    logger.info("sadads")
    logger.disabled = disabled



import argparse
import os
import sys
from typing import Dict, Any

from pyqt6rc import __version__
from pyqt6rc.convert_tools import (
    ui_to_py,
    modify_py,
    save_py,
    get_ui_files,
    update_resources,
)
from pyqt6rc.script_helpers import set_logger

description = [
    f"pyqt6rc v{__version__}",
    "PyQt6 UI templates - Resource Converter.",
    "Default input location is Current Working Directory.",
    "",
    "Usage examples:",
    "  Convert all .ui files in CWD:",
    "  pyqt6rc",
    "",
    "  Convert all .ui files in CWD using importlib_resources:",
    "  pyqt6rc -c",
    "",
    "  Convert all .ui files in directory:",
    "  pyqt6rc -i /directory/with/templates",
    "",
    "  Convert all .ui files in CWD, save output in different directory:",
    "  pyqt6rc -o /directory/with/converted/templates",
    "",
]

arguments = sys.argv
parser = argparse.ArgumentParser(
    formatter_class=argparse.RawTextHelpFormatter, description="\r\n".join(description)
)
parser.add_argument(
    "input",
    type=str,
    help="Path to .ui template file or Directory containing .ui files."
    "If empty, scan current working directory and use all .ui template files.",
    default="*",
    nargs="?",
)
parser.add_argument(
    "-tb", "--tab_size", type=int, help="Size of tab in spaces, default=4", default=4
)
parser.add_argument(
    "-o",
    "--out",
    type=str,
    help="Output directory to save converted templates",
    default=None,
)
parser.add_argument("-s", "--silent", help="Supress logging", action="store_true")
parser.add_argument(
    "-c",
    "--compatible",
    help="Use compatible importlib_resources instead of native importlib."
    "Requires importlib_resources.",
    action="store_true",
)
args = parser.parse_args()

# Set logger
set_logger(args.silent)

# Input files check
if args.input == "*":
    input_files = get_ui_files(os.getcwd())
elif os.path.isdir(args.input):
    input_files = get_ui_files(args.input)
else:
    if not args.input.endswith(".ui"):
        raise Exception(f"Not template file {args.input}.")
    if not os.path.exists(args.input):
        raise Exception(f"Template file {args.input} does not exists.")
    input_files = [args.input]


def run() -> None:
    resources: Dict[str, Any] = {}
    for input_file in input_files:
        resources_found = update_resources(input_file, resources)
        py_input = ui_to_py(input_file)
        # Skip conversion if no resource were found in input template file
        if resources_found is not None:
            py_input = modify_py(py_input, resources, args.tab_size, args.compatible)
        save_py(input_file, py_input, args.out)



import os.path
from typing import Dict, Any

import pytest


from pyqt6rc.convert_tools import (
    parse_qrc,
    ui_to_py,
    modify_py,
    get_ui_files,
    save_py,
    update_resources,
    modify_py_sp,
)


def test_qrc_parse() -> None:
    parsed_qrc = parse_qrc("pyqt6rc/test/test_resources/resources.qrc")
    assert parsed_qrc == {
        "/": {"aliases": {}, "module_path": ""},
        "/icons/": {"aliases": {}, "module_path": ""},
        "/subdir/icons/": {"aliases": {}, "module_path": ""},
        "/subdir/icons_aliased/": {
            "aliases": {"test.png": "aliased.png"},
            "module_path": "",
        },
    }


def test_broken_qrc_parse() -> None:
    with pytest.raises(Exception):
        parse_qrc("pyqt6rc/test/test_resources/broken_resources.qrc")


@pytest.mark.parametrize("compatible", [False, True])
def test_conversion(compatible: bool) -> None:
    reference_file = (
        "template1_reference_compatible.py" if compatible else "template1_reference.py"
    )

    resources: Dict[str, Any] = {}
    update_resources(
        "pyqt6rc/test/test_resources/myPackage/templates/template1.ui", resources
    )
    convert_ui_to_py = ui_to_py(
        "pyqt6rc/test/test_resources/myPackage/templates/template1.ui"
    )
    modified_py = modify_py(convert_ui_to_py, resources, compatible=compatible)

    with open(
        f"pyqt6rc/test/test_resources/myPackage/templates/{reference_file}", "r"
    ) as fp:
        assert fp.read().split("\n", 6)[5] == modified_py.split("\n", 6)[5]


def test_sp_conversion() -> None:
    reference_file = "template1_sp_reference.py"

    resources: Dict[str, Any] = {}
    resource_rel_path = update_resources(
        "pyqt6rc/test/test_resources/myPackage/templates/template1.ui", resources
    )
    convert_ui_to_py = ui_to_py(
        "pyqt6rc/test/test_resources/myPackage/templates/template1.ui"
    )
    modified_py = modify_py_sp(convert_ui_to_py, resources, resource_rel_path)

    with open(
        f"pyqt6rc/test/test_resources/myPackage/templates/{reference_file}", "r"
    ) as fp:
        assert fp.read().split("\n", 6)[5] == modified_py.split("\n", 6)[5]


def test_sp_conversion_no_resources() -> None:
    reference_file = "template3_reference.py"

    resources: Dict[str, Any] = {}
    resource_rel_path = update_resources(
        "pyqt6rc/test/test_resources/myPackage/templates/template3.ui", resources
    )
    convert_ui_to_py = ui_to_py(
        "pyqt6rc/test/test_resources/myPackage/templates/template3.ui"
    )
    modified_py = modify_py_sp(convert_ui_to_py, resources, resource_rel_path)

    with open(
        f"pyqt6rc/test/test_resources/myPackage/templates/{reference_file}", "r"
    ) as fp:
        assert fp.read().split("\n", 6)[5] == modified_py.split("\n", 6)[5]


def test_get_ui_files() -> None:
    ui_files = get_ui_files("pyqt6rc/test/test_resources/myPackage/templates")
    assert "pyqt6rc/test/test_resources/myPackage/templates/template3.ui" in ui_files
    assert "pyqt6rc/test/test_resources/myPackage/templates/template2.ui" in ui_files
    assert "pyqt6rc/test/test_resources/myPackage/templates/template1.ui" in ui_files


def test_save_py() -> None:
    parsed_qrc = parse_qrc(
        "pyqt6rc/test/test_resources/myPackage/resources/resources.qrc"
    )
    for template_name in ("template1", "template2"):
        convert_ui_to_py = ui_to_py(
            f"pyqt6rc/test/test_resources/myPackage/templates/{template_name}.ui"
        )
        modified_py = modify_py(convert_ui_to_py, parsed_qrc)

        save_py(
            f"pyqt6rc/test/test_resources/myPackage/templates/{template_name}.ui",
            modified_py,
            "pyqt6rc/test/",
        )
        assert os.path.isfile(f"pyqt6rc/test/{template_name}.py")

        try:
            with open(f"pyqt6rc/test/{template_name}.py", "r") as fp:
                assert fp.read().split("\n", 6)[5] == modified_py.split("\n", 6)[5]
        finally:
            os.remove(f"pyqt6rc/test/{template_name}.py")
